@@ -3,8 +3,8 @@
  * Date  : 2004-06-26
  * Description :
  *
- * Copyright 2004 by Renchi Raju
-
+ * Copyright 2004-2005 by Renchi Raju <renchi@pooh.tam.uiuc.edu>
+ *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
  * Public License as published by the Free Software Foundation;
@@ -18,6 +18,20 @@
  *
  * ============================================================ */
 
+// C Ansi includes.
+
+extern "C"
+{
+#include <sys/time.h>
+}
+
+// C++ includes.
+
+#include <cstdio>
+#include <ctime>
+
+// Qt includes.
+
 #include <qstring.h>
 #include <qcstring.h>
 #include <qdatastream.h>
@@ -28,39 +42,56 @@
 #include <qvaluelist.h>
 #include <qtimer.h>
 
-#include <kdebug.h>
+// KDE includes.
+
+#include <kapplication.h>
+#include <kcursor.h>
 #include <kio/job.h>
 #include <kurl.h>
 
+// Local includes.
+
+#include "ddebug.h"
 #include "album.h"
 #include "albummanager.h"
 #include "albumsettings.h"
-
 #include "albumlister.h"
 
-extern "C"
+namespace Digikam
 {
-#include <sys/time.h>
-#include <time.h>
-#include <stdio.h>
-}
 
 class AlbumListerPriv
 {
 public:
 
-    KIO::TransferJob*          job;
-    QString                    filter;
+    AlbumListerPriv()
+    {
+        filterTimer  = 0;
+        job          = 0;
+        currAlbum    = 0;
+        filter       = "*";
+        matchingCond = AlbumLister::OrCondition;
+    }
 
-    Album*                     currAlbum;
+    bool                            untaggedFilter;
 
-    QMap<int,bool>             dayFilter;
-    QValueList<int>            tagFilter;
-    bool                       untaggedFilter;
-    QTimer*                    filterTimer;
+    QString                         filter;
 
-    ImageInfoList              itemList;
-    QMap<Q_LLONG, ImageInfo*>  itemMap;
+    QMap<Q_LLONG, ImageInfo*>       itemMap;
+    QMap<int,int>                   invalidatedItems;
+    QMap<int,bool>                  dayFilter;
+
+    QValueList<int>                 tagFilter;
+
+    QTimer                         *filterTimer;
+
+    KIO::TransferJob               *job;
+
+    ImageInfoList                   itemList;
+
+    Album                          *currAlbum;
+
+    AlbumLister::MatchingCondition matchingCond;
 };
 
 AlbumLister* AlbumLister::m_instance = 0;
@@ -78,15 +109,12 @@ AlbumLister::AlbumLister()
     m_instance = this;
 
     d = new AlbumListerPriv;
-    d->job       = 0;
-    d->currAlbum = 0;
-    d->filter    = "*";
     d->itemList.setAutoDelete(true);
     d->untaggedFilter = false;
-    d->filterTimer = new QTimer(this);
+    d->filterTimer    = new QTimer(this);
 
     connect(d->filterTimer, SIGNAL(timeout()),
-            SLOT(slotFilterItems()));
+            this, SLOT(slotFilterItems()));
 }
 
 AlbumLister::~AlbumLister()
@@ -123,10 +151,12 @@ void AlbumLister::openAlbum(Album *album)
     // Protocol = digikamalbums -> kio_digikamalbums
     d->job = new KIO::TransferJob(album->kurl(), KIO::CMD_SPECIAL,
                                   ba, QByteArray(), false);
+
     connect(d->job, SIGNAL(result(KIO::Job*)),
-            SLOT(slotResult(KIO::Job*)));
+            this, SLOT(slotResult(KIO::Job*)));
+
     connect(d->job, SIGNAL(data(KIO::Job*, const QByteArray&)),
-            SLOT(slotData(KIO::Job*, const QByteArray&)));
+            this, SLOT(slotData(KIO::Job*, const QByteArray&)));
 }
 
 void AlbumLister::refresh()
@@ -158,10 +188,12 @@ void AlbumLister::refresh()
 
     d->job = new KIO::TransferJob(d->currAlbum->kurl(), KIO::CMD_SPECIAL,
                                   ba, QByteArray(), false);
+
     connect(d->job, SIGNAL(result(KIO::Job*)),
-            SLOT(slotResult(KIO::Job*)));
+            this, SLOT(slotResult(KIO::Job*)));
+
     connect(d->job, SIGNAL(data(KIO::Job*, const QByteArray&)),
-            SLOT(slotData(KIO::Job*, const QByteArray&)));
+            this, SLOT(slotData(KIO::Job*, const QByteArray&)));
 }
 
 void AlbumLister::setDayFilter(const QValueList<int>& days)
@@ -174,11 +206,12 @@ void AlbumLister::setDayFilter(const QValueList<int>& days)
     d->filterTimer->start(100, true);
 }
 
-void AlbumLister::setTagFilter(const QValueList<int>& tags, bool showUnTagged)
+void AlbumLister::setTagFilter(const QValueList<int>& tags, const MatchingCondition& matchingCond, 
+                               bool showUnTagged)
 {
-    d->tagFilter = tags;
+    d->tagFilter      = tags;
+    d->matchingCond   = matchingCond;
     d->untaggedFilter = showUnTagged;
-
     d->filterTimer->start(100, true);
 }
 
@@ -193,15 +226,32 @@ bool AlbumLister::matchesFilter(const ImageInfo* info) const
     if (!d->tagFilter.isEmpty())
     {
         QValueList<int> tagIDs = info->tagIDs();
-        for (QValueList<int>::iterator it = d->tagFilter.begin();
-             it != d->tagFilter.end(); ++it)
+        QValueList<int>::iterator it;
+
+        if (d->matchingCond == OrCondition)        
         {
-            if (tagIDs.contains(*it))
+            for (it = d->tagFilter.begin(); it != d->tagFilter.end(); ++it)
             {
-                match = true;
-                break;
+                if (tagIDs.contains(*it))
+                {
+                    match = true;
+                    break;
+                }
             }
         }
+        else
+        {
+            // AND matching condition...
+
+            for (it = d->tagFilter.begin(); it != d->tagFilter.end(); ++it)
+            {
+                if (!tagIDs.contains(*it))
+                    break;
+            }
+    
+            if (it == d->tagFilter.end())
+                match = true;
+        }
 
         match |= (d->untaggedFilter && tagIDs.isEmpty());
     }
@@ -227,6 +277,7 @@ void AlbumLister::stop()
     d->currAlbum = 0;
     d->filterTimer->stop();
     emit signalClear();
+
     d->itemList.clear();
     d->itemMap.clear();
 
@@ -242,6 +293,11 @@ void AlbumLister::setNameFilter(const QString& nameFilter)
     d->filter = nameFilter;
 }
 
+void AlbumLister::invalidateItem(const ImageInfo *item)
+{
+    d->invalidatedItems.insert(item->id(), item->id());
+}
+
 void AlbumLister::slotClear()
 {
     emit signalClear();
@@ -256,6 +312,7 @@ void AlbumLister::slotFilterItems()
     }
 
     QPtrList<ImageInfo> newFilteredItemsList;
+    QPtrList<ImageInfo> deleteFilteredItemsList;
 
     ImageInfo* item;
     for (ImageInfoListIterator it(d->itemList);
@@ -269,12 +326,27 @@ void AlbumLister::slotFilterItems()
         else
         {
             if (item->getViewItem())
-                emit signalDeleteFilteredItem(item);
+                deleteFilteredItemsList.append(item);
         }
     }
 
+    // This takes linear time - and deleting seems to take longer. Set wait cursor for large numbers.
+    bool setCursor = (3*deleteFilteredItemsList.count() + newFilteredItemsList.count()) > 1500;
+    if (setCursor)
+        kapp->setOverrideCursor(KCursor::waitCursor());
+
+    if (!deleteFilteredItemsList.isEmpty())
+    {
+        for (ImageInfo *info=deleteFilteredItemsList.first(); info; info = deleteFilteredItemsList.next())
+            emit signalDeleteFilteredItem(info);
+    }
     if (!newFilteredItemsList.isEmpty())
+    {
         emit signalNewFilteredItems(newFilteredItemsList);
+    }
+
+    if (setCursor)
+        kapp->restoreOverrideCursor();
 }
 
 void AlbumLister::slotResult(KIO::Job* job)
@@ -283,12 +355,12 @@ void AlbumLister::slotResult(KIO::Job* job)
 
     if (job->error())
     {
-        kdWarning() << "Failed to list url: " << job->errorString() << endl;
+        DWarning() << "Failed to list url: " << job->errorString() << endl;
         d->itemMap.clear();
+        d->invalidatedItems.clear();
         return;
     }
 
-
     typedef QMap<Q_LLONG, ImageInfo*> ImMap;
 
     for (ImMap::iterator it = d->itemMap.begin();
@@ -300,6 +372,7 @@ void AlbumLister::slotResult(KIO::Job* job)
     }
 
     d->itemMap.clear();
+    d->invalidatedItems.clear();
 
     emit signalCompleted();
 }
@@ -313,13 +386,14 @@ void AlbumLister::slotData(KIO::Job*, const QByteArray& data)
     int     albumID;
     QString name;
     QString date;
-    off_t   size;
+    size_t  size;
     QSize   dims;
 
     ImageInfoList newItemsList;
     ImageInfoList newFilteredItemsList;
 
     QDataStream ds(data, IO_ReadOnly);
+
     while (!ds.atEnd())
     {
         ds >> imageID;
@@ -332,22 +406,31 @@ void AlbumLister::slotData(KIO::Job*, const QByteArray& data)
         if (d->itemMap.contains(imageID))
         {
             ImageInfo* info = d->itemMap[imageID];
-            if (!matchesFilter(info))
-            {
-                emit signalDeleteFilteredItem(info);
-            }
-            
             d->itemMap.remove(imageID);
-            continue;
+
+            if (d->invalidatedItems.contains(imageID))
+            {
+                emit signalDeleteItem(info);
+                emit signalDeleteFilteredItem(info);
+                d->itemList.remove(info);
+            }
+            else
+            {
+                if (!matchesFilter(info))
+                {
+                    emit signalDeleteFilteredItem(info);
+                }
+                continue;
+            }
         }
 
         ImageInfo* info = new ImageInfo(imageID, albumID, name,
-                                        QDateTime::fromString(date,
-                                                              Qt::ISODate),
+                                        QDateTime::fromString(date, Qt::ISODate),
                                         size, dims);
 
         if (matchesFilter(info))
             newFilteredItemsList.append(info);
+
         newItemsList.append(info);
         d->itemList.append(info);
     }
@@ -359,5 +442,7 @@ void AlbumLister::slotData(KIO::Job*, const QByteArray& data)
         emit signalNewItems(newItemsList);
 }
 
+}  // namespace Digikam
+
 #include "albumlister.moc"
 
