@@ -1,7 +1,7 @@
 /* ============================================================
  * Author: Renchi Raju <renchi@pooh.tam.uiuc.edu>
  * Date  : 2005-05-20
- * Copyright 2005 by Renchi Raju
+ * Copyright 2005 by Renchi Raju <renchi@pooh.tam.uiuc.edu>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -18,8 +18,13 @@
 #ifndef SEARCHRESULTSITEM_H
 #define SEARCHRESULTSITEM_H
 
+// Qt includes.
+
 #include <qiconview.h>
 
+namespace Digikam
+{
+
 class SearchResultsItem : public QIconViewItem
 {
     friend class SearchResultsView;
@@ -31,7 +36,7 @@ public:
 
 protected:
 
-    void calcRect(const QString& text = QString::null);
+    void calcRect(const QString& text = QString());
     void paintItem (QPainter * p, const QColorGroup & cg);
     void paintFocus (QPainter * p, const QColorGroup & cg);
 
@@ -42,5 +47,6 @@ private:
     QString         m_path;
 };    
     
+}  // namespace Digikam
 
 #endif /* SEARCHRESULTSITEM_H */
